@@ -5,10 +5,11 @@ Regexp::Common::time - Date and time regexps.
 =cut
 
 use strict;
+use warnings;
+
 package Regexp::Common::time;
-$Regexp::Common::time::VERSION = '0.06';
+$Regexp::Common::time::VERSION = '0.08';
 use Regexp::Common qw(pattern);
-use POSIX;
 
 sub _croak { require Carp; goto &Carp::croak}
 
@@ -1415,4 +1416,3 @@ endeavor to improve the software.
 
 
 =cut
-
